diff --git a/src/Microsoft.PowerShell.Commands.Omi/test/Start-DscConfiguration.Tests.ps1 b/src/Microsoft.PowerShell.Commands.Omi/test/Start-DscConfiguration.Tests.ps1
index 1fe1a39c38..4ac1b56b75 100644
--- a/src/Microsoft.PowerShell.Commands.Omi/test/Start-DscConfiguration.Tests.ps1
+++ b/src/Microsoft.PowerShell.Commands.Omi/test/Start-DscConfiguration.Tests.ps1
@@ -22,13 +22,13 @@ Describe "DscConfiguration" {
}
It "Should set Meta MOF file properly" {
- $s = Set-DscLocalConfiguration -ConfigurationMof $mofMeta |
+ $s = Set-DscLocalConfigurationManager -ConfigurationMof $mofMeta |
Where-Object {$_.NAME -eq "ReturnValue"}
$s.VALUE | Should Be "0"
}
It "Should get DSC local configuration successfully" {
- $s = Get-DscLocalConfiguration | Where-Object {$_.NAME -eq "ReturnValue"}
+ $s = Get-DscLocalConfigurationManager | Where-Object {$_.NAME -eq "ReturnValue"}
$s.VALUE | Should Be "0"
}
diff --git a/src/Microsoft.PowerShell.Commands.Omi/DscLocalConfiguration.cs b/src/Microsoft.PowerShell.Commands.Omi/DscLocalConfiguration.cs
index fa09bf5acd..1f5dbe2ced 100644
--- a/src/Microsoft.PowerShell.Commands.Omi/DscLocalConfiguration.cs
+++ b/src/Microsoft.PowerShell.Commands.Omi/DscLocalConfiguration.cs
@@ -8,14 +8,14 @@ using System.Management.Automation;
namespace Microsoft.PowerShell.Commands.Omi
{
- #region Set-DscLocalConfiguration
+ #region Set-DscLocalConfigurationManager
///
/// implementation for the Set-DscLocalConfiguration command
///
- [Cmdlet(VerbsCommon.Set, "DscLocalConfiguration" )]
+ [Cmdlet(VerbsCommon.Set, "DscLocalConfigurationManager" )]
[OutputType(typeof(object))]
- public sealed class SetDscLocalConfigurationCommand : Cmdlet
+ public sealed class SetDscLocalConfigurationManagerCommand : Cmdlet
{
#region parameters
@@ -85,14 +85,14 @@ namespace Microsoft.PowerShell.Commands.Omi
#endregion
- #region Get-DscConfiguration
+ #region Get-DscLocalConfigurationManager
///
/// implementation for the Get-DscLocalConfiguration command
///
- [Cmdlet(VerbsCommon.Get, "DscLocalConfiguration" )]
+ [Cmdlet(VerbsCommon.Get, "DscLocalConfigurationManager" )]
[OutputType(typeof(object))]
- public sealed class GetDscLocalConfigurationCommand : Cmdlet
+ public sealed class GetDscLocalConfigurationManagerCommand : Cmdlet
{
#region methods
@@ -85,14 +85,14 @@ namespace Microsoft.PowerShell.Commands.Omi
///
- /// implementation for the Get-DscLocalConfiguration command
+ /// implementation for the Get-DscLocalConfigurationManager command
///